#
# spec file for package grantlee5
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without tests

%{?!cmake_build:%global cmake_build() make %{?_smp_mflags} VERBOSE=1}
%{?!cmake_install:%global cmake_install() DESTDIR=%{buildroot} make install}

Name:           grantlee5
Version:        5.3.1
Release:        2.4
Summary:        Qt string template library
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://github.com/steveire/grantlee
Source:         https://github.com/steveire/grantlee/releases/download/v%{version}/grantlee-%{version}.tar.gz
Source2:        baselibs.conf
Source3:        grantlee5.keyring
# PATCH-FIX-OPENSUSE includes.diff -- since upstream doesn't provide a way to install to custom directory, we cheat!
Patch0:         includes.diff
# PATCH-FIX-OPENSUSE grantlee-5.2.0-fix-ctest-ld-library-path.patch -- set ld library path for tests
Patch1:         grantlee-5.2.0-fix-ctest-ld-library-path.patch
# PATCH-FIX-UPSTREAM https://github.com/steveire/grantlee/pull/86/
Patch2:         fix-i586-precision.patch
# PATCH-FIX-UPSTREAM https://github.com/steveire/grantlee/issues/89
Patch3:         0001-Add-a-call-to-registerComparators-in-testbuiltins.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  cmake(Qt5Core) >= 5.3
BuildRequires:  cmake(Qt5Gui) >= 5.3
BuildRequires:  cmake(Qt5Qml) >= 5.3
%if %{with tests}
BuildRequires:  /usr/bin/Xvfb
BuildRequires:  xvfb-run
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Test) >= 5.3
%endif

%description
Grantlee is a string template engine based on the Django template system and
written in Qt.

%package devel
Summary:        Include Files and Libraries Mandatory for Development with Grantlee
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       cmake >= 3.5
Requires:       cmake(Qt5Core) >= 5.3
Requires:       cmake(Qt5Gui) >= 5.3

%description devel
This package contains include files and libraries needed for development with
grantlee.

%prep
%autosetup -p1 -n grantlee-%{version}

%build
%cmake \
  %{!?with_tests:-DBUILD_TESTS:BOOL=OFF}

%cmake_build

%install
%cmake_install

%if %{with tests}
%check
export CTEST_OUTPUT_ON_FAILURE=1
xvfb-run -a make test -C %{__builddir}
%endif

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING*
%doc AUTHORS CHANGELOG README*
%{_libdir}/libGrantlee_TextDocument.so.*
%{_libdir}/libGrantlee_Templates.so.*
%{_libdir}/grantlee/

%files devel
%license COPYING*
%doc AUTHORS CHANGELOG README*
%{_includedir}/grantlee5/
%{_libdir}/libGrantlee_TextDocument.so
%{_libdir}/libGrantlee_Templates.so
%{_libdir}/cmake/Grantlee5/

%changelog
* Tue May 23 2023 Christophe Marin <christophe@krop.fr>
- Add patch to fix test failures on Leap 15:
  * 0001-Add-a-call-to-registerComparators-in-testbuiltins.patch
* Sun Nov 13 2022 Luca Beltrame <lbeltrame@kde.org>
- Update to 5.3.1
  * Use C++11 nullptr where appropriate
  * Use QRandomGenerator instead of deprecated qRand
  * Increase compatibility with Qt 6 APIs
  * Add CMake option to build with Qt 6 - GRANTLEE_BUILD_WITH_QT6
  * Support enum introspection on Q_GADGET
  * filesizeformat implementation as well as localized filesize
  * Make enums comparable with more operations
  * Add "truncatechars" filter
  * Fix concatenation of string lists
- Refreshed patches:
  * includes.diff
  * grantlee-5.2.0-fix-ctest-ld-library-path.patch
- Add patch to fix tests on i586 (gh#steveire/grantlee#85):
  * fix-i586-precision.patch
- Add keyring for GPG source verification
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Don't ignore the exit code of make test
* Tue Mar 31 2020 Matthias Fehring <buschmann23@opensuse.org>
- Require cmake(Qt5LinguistTools) for building to enable testing of
  internationalization
- Use xvfb-run to run all tests, this obsoletes the following patch:
  * grantlee-5.2.0-disable-textdocument-tests.patch
* Thu Dec 19 2019 Matthias Fehring <buschmann23@opensuse.org>
- Enable and run tests
  * add grantlee-5.2.0-fix-ctest-ld-library-path.patch to set correct
    ld library path as we skip rpath
  * add grantlee-5.2.0-disable-textdocument-tests.patch to disable
    some tests
* Wed Dec 18 2019 Matthias Fehring <buschmann23@opensuse.org>
- Update to 5.2.0
  * Increase CMake requirement to version 3.5
  * Port scriptable extensions to QJSEngine provided by QtQml
  * Support reading properties from Q_GADGETS
  * Remove TestCocoon integration
  * Clean up documentation to clarify introspection requirements
  * Fix mixing of {%% include %%} and {%% extends %%} tags
  * Fix various bugs discovered by fuzzing
  * Remove use of TR1 library features from unit tests
  * Remove obsolete build options
  * Document that loading templates from Qt Resources is possible
- Remove obsolete patches now included upstream
  * fix-build-with-Qt-5.13.patch
  * 0001-Remove-vestigial-ansi-flag.patch
  * 0002-Fix-mix-of-inclusion-and-extension.patch
- Rebase pachtes
  * includes.diff
* Mon Dec  9 2019 Matthias Fehring <buschmann23@opensuse.org>
- Add patch to fix segfault when mixing include and extend
  * 0002-Fix-mix-of-inclusion-and-extension.patch
* Wed Jul 31 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build with newer CMake:
  * 0001-Remove-vestigial-ansi-flag.patch
* Wed Apr 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-build-with-Qt-5.13.patch
- Run spec-cleaner
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * Implement advanced operators for the {%% if %%} tag
  * Use 'd' postfix for plugins built in debug mode
  * Use 'd' postfix for libraries built in debug mode by Visual Studio
  * Make it possible to build without QtScript and QtLinguistTools
  * Bump Grantlee CMake requirement to 3.1.
  * Bump Grantlee Qt requirement to 5.3.
* Wed Jan  7 2015 hrvoje.senjan@gmail.com
- Move away from using kf5-filesystem, only users of KDEInstallDirs
  should use it
* Wed Sep 24 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0 final:
  * No changelog since rc1 provided
* Mon Sep 22 2014 hrvoje.senjan@gmail.com
- Activate grantlee5 package, Qt5 based variant of the grantlee libs
- Update to 5.0.0~rc1
  * Drop Qt 4 build. Make Qt 5 a hard requirement.
  * Add a porting guide for users of old versions of Grantlee.
  * Drop custom handling of QObjects and containers in QVariant.
  * Drop old names 'grantlee_core' and 'grantlee_gui' in favor of
    'Templates' and 'Textdocument' respectively.
  * Rely on modern CMake features such as IMPORTED targets and
    usage requirements.
  * Bump Grantlee CMake requirement to 2.8.12.
  * Make the virtual Grantlee::Node::render method const.
  * Merge LocalizedFilesystemTemplateLoader
    into FilesystemTemplateLoader.
  * Remove typedefs for QSharedPointers from APIs.
- Bump miminal requied cmake version to 2.8.12
- Add includes.diff: since upstream doesn't provide a way to install
  to custom directory, we cheat!
- Add baselibs.conf
* Sat Nov 30 2013 hrvoje.senjan@gmail.com
- Update to 0.4.0
  * Bump Grantlee CMake requirement to 2.8.9.
  * Use the CMAKE_AUTOMOC feature in Grantlee.
  * Clean up all CMake code.
  * Fix memory leak when deleting a localized template loader.
  * Clean up C++ code in preparation for Qt 5.
  * Update jQuery version used in example to the latest release.
  * Add API for resolving variables to strings in QtScript.
  * Fix tests on ARM and other platforms which use float for qreal.
* Fri Nov  2 2012 cgiboudeaux@gmx.com
- Update to 0.3.0
  * Implement dictsort filter
  * Many new unit tests
  * Bug fixes and performance improvements
  * Roman numeral support in textdocument processing
* Sat Nov  5 2011 asterios.dramis@gmail.com
- Update to version 0.2.0:
  * Fix build on several platforms including mac, solaris and bsds.
  * Gather coverage data in release builds instead of debug builds.
  * Ensure that unit tests can be run and pass before installation.
  * Ensure that unit tests pass in multiple locales.
  * Fix several compiler warnings.
  * Add options for generating coverage data using testcocoon.
- Spec file updates:
  * Renamed License: to LGPL-2.1+.
  * Spec-cleaner run.
* Thu Jul  7 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Added Provides/Obsoletes for grantlee.
* Wed Jul  6 2011 asterios.dramis@gmail.com
- update to version 0.1.9
  * Port the lexer to a state machine based string parser.
  * Add feature to trim insignificant whitespace.
  * Build with stricter Qt flags QT_NO_KEYWORDS and QT_NO_CAST_FROM_BYTEARRAY.
  * Add example application for a html based templated application framework.
  * Add documentation and convenience functions for QObject and Q_PROPERTY
    introspection.
  * Modernise the CMake build system including creation of EXPORT targets and
    fixing of various cross-platform issues.
  * Add a componentized CPack packaging system for binary tarballs and windows
    install wizards.
  * Ability to use COMPONENTS argument to find_package with Grantlee.
  * Add a build target for generating code coverage information.
  * Platform fixes for MIPS, ARM and MinGW.
  * Add more documentation for example applications shipped with the Grantlee
    source.
  * Add the changelog for prior versions of Grantlee.
- Spec file updates:
  * Added lcov in BuildRequires:.
  * Changes based on openSUSE shared library packaging policy (added
    libgrantlee_core0 and libgrantlee_gui0 packages, removed grantlee
    package).
  * Minor other updates.
* Sun May 22 2011 asterios.dramis@gmail.com
- update to version 0.1.8
  * Add support for internationalization and localization features.
  * A new contacts/address book application.
  * Support for outputting QDate and QTime objects.
  * Automatic loading of QtScript based plugins.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPLv2.1+.
  * Updates in Group:, Summary: and %%description entries.
  * Removed libopenssl-devel from BuildRequires: (not needed).
  * Removed /sbin/ldconfig from devel package (not needed).
  * Minor other updates.
* Tue Dec 14 2010 wstephenson@novell.com
- Revert to 0.1.7 and tidy specfile
* Thu Oct 28 2010 tittiatcoke@gmail.com
- Went back to version 0.1.6 due to build issues. (Hanging build)
* Sun Oct 24 2010 wstephenson@novell.com
- update to version 0.1.7
  * Generic type support
  * Licensing fixes
  * Documentation fixes
* Thu Sep 30 2010 wstephenson@novell.com
- update to version 0.1.6
  * Fixed memory leaks
  * More strict casting from ascii
* Fri Sep 10 2010 tittiatcoke@gmail.com
- update to version 0.1.5
* Mon Jul 19 2010 freitag@novell.com
- update to version 0.1.3
* Mon Apr 19 2010 tittiatcoke@gmail.com
- Official release for version 0.1
* Fri Apr  9 2010 tittiatcoke@gmail.com
- Initial package
